# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["EvaluationItemExportParams"]


class EvaluationItemExportParams(TypedDict, total=False):
    evaluation_id: Required[str]
    """The ID of the evaluation to export items from."""

    export_format: Literal["json", "jsonl", "csv"]
    """The format of the exported evaluation items.

    `json` returns a single JSON array, while `jsonl` returns one JSON object per
    line.
    """

    export_method: Literal["signed_url", "direct"]
    """The method for exporting evaluation items.

    `signed_url` returns a pre-signed URL, while `direct` returns the raw content.
    """

    include_archived: bool
    """If true, include archived evaluation items in the export."""
