# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["DatasetItemRetrieveParams"]


class DatasetItemRetrieveParams(TypedDict, total=False):
    version: int
    """Optional dataset version. When unset, returns the latest version."""
